package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcPlaceManage;
import com.ruoyi.szxc.mapper.SzxcPlaceManageMapper;
import com.ruoyi.szxc.service.ISzxcPlaceManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 场所管理Service业务层处理
 * 
 * @author hs
 * @date 2024-03-28
 */
@Service
public class SzxcPlaceManageServiceImpl implements ISzxcPlaceManageService 
{
    @Autowired
    private SzxcPlaceManageMapper szxcPlaceManageMapper;

    /**
     * 查询场所管理
     * 
     * @param id 场所管理主键
     * @return 场所管理
     */
    @Override
    public SzxcPlaceManage selectSzxcPlaceManageById(Long id)
    {
        return szxcPlaceManageMapper.selectSzxcPlaceManageById(id);
    }

    /**
     * 查询场所管理列表
     * 
     * @param szxcPlaceManage 场所管理
     * @return 场所管理
     */
    @Override
    @DataScope(deptAlias = "p")
    public List<SzxcPlaceManage> selectSzxcPlaceManageList(SzxcPlaceManage szxcPlaceManage)
    {
        return szxcPlaceManageMapper.selectSzxcPlaceManageList(szxcPlaceManage);
    }

    /**
     * 新增场所管理
     * 
     * @param szxcPlaceManage 场所管理
     * @return 结果
     */
    @Override
    public int insertSzxcPlaceManage(SzxcPlaceManage szxcPlaceManage)
    {
        szxcPlaceManage.setCreateTime(DateUtils.getNowDate());
        return szxcPlaceManageMapper.insertSzxcPlaceManage(szxcPlaceManage);
    }

    /**
     * 修改场所管理
     * 
     * @param szxcPlaceManage 场所管理
     * @return 结果
     */
    @Override
    public int updateSzxcPlaceManage(SzxcPlaceManage szxcPlaceManage)
    {
        szxcPlaceManage.setUpdateTime(DateUtils.getNowDate());
        return szxcPlaceManageMapper.updateSzxcPlaceManage(szxcPlaceManage);
    }

    /**
     * 批量删除场所管理
     * 
     * @param ids 需要删除的场所管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcPlaceManageByIds(Long[] ids)
    {
        return szxcPlaceManageMapper.deleteSzxcPlaceManageByIds(ids);
    }

    /**
     * 删除场所管理信息
     * 
     * @param id 场所管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcPlaceManageById(Long id)
    {
        return szxcPlaceManageMapper.deleteSzxcPlaceManageById(id);
    }
}
